.. _utils:

Utilities Module
================

.. automodule:: eyetrace.utils
   :members:
   :undoc-members:
   :show-inheritance:

The `utils` module provides low-level helper functions used across
EyeTrace. It includes landmark extraction, signal filtering, geometric
calculations, and general mathematical tools.

.. toctree::
   :maxdepth: 1
   :caption: Submodules

   utils.landmarks
   utils.filtering
   utils.geometry
   utils.math_helpers